@@ -14,8 +14,8 @@ from __future__ import annotations
 
 from argparse import ArgumentParser
 
-from snippyFile import SnippetFromDocument, SnippetFromClipboard
-from snippyStatus import Status
+from snippycode.snippyFile import SnippetFromDocument, SnippetFromClipboard
+from snippycode.snippyStatus import Status
 
 
 def json_choice(arguments):
