@@ -13,7 +13,7 @@ from json import loads, dumps
 from os import getenv
 from os.path import join, exists
 
-from snippyJson import Json, JsonFromDocument, JsonFromClipboard
+from snippycode.snippyJson import Json, JsonFromDocument, JsonFromClipboard
 
 ENCODING: str = "utf-8"
 HELLO   : dict = {"Snippycode":{
